# JKQC
Jammy Key for Quantum Chemistry

You can install with `pip install -e .`

Here is an example:

.. code:

   git clone https://github.com/kubeckaj/JKQC.git
   cd JKQC
   python -m venv .venv
   source .venv/bin/activate
   pip install -e .
   jkqc --help

.. note:
 
   Make sure you use the correct python version


